@@ -65,7 +65,7 @@
 //!       },
 //!       Item::String {
 //!         name: "String0".to_string(),
-//!         hotkey: Some('s'),
+//!         hotkey: Some('t'),
 //!         exp: Some("String0 Explanation.".to_string()),
 //!       },
 //!       Item::F64 {
@@ -203,6 +203,8 @@ pub struct Selection {
   pub path: Vec<String>,
   /// Input by user, if it exists.
   pub value: Option<Value>,
+  /// Number of attempts of input.
+  pub attempt: Option<i32>,
 }
 /// Input by user.
 #[derive(Debug, PartialEq)]
@@ -385,18 +387,18 @@ impl Menu {
     if *key == None {
       return Err("No Selection".to_string());
     } else if is_sub && *key == Some("Back".to_string()) {
-      self.flush_stdout(stdout_ins);
+      self.clear_menu(stdout_ins);
       return Err("Back".to_string());
     } else if *key == Some("Exit".to_string()) {
       if self.esc {
-        self.flush_stdout(stdout_ins);
+        self.clear_menu(stdout_ins);
         stdout_ins.flush().unwrap();
         return Err("Exit".to_string());
       }
     } else if *key == Some("Up".to_string()) {
       if *hover > 0 {
         *hover -= 1;
-        self.flush_stdout(stdout_ins);
+        self.clear_menu(stdout_ins);
         if path.len() == 1 {
           return self.printer(stdout_ins, hover);
         } else {
@@ -406,7 +408,7 @@ impl Menu {
     } else if *key == Some("Down".to_string()) {
       if (*hover + 1) < self.items.len() {
         *hover += 1;
-        self.flush_stdout(stdout_ins);
+        self.clear_menu(stdout_ins);
         if path.len() == 1 {
           return self.printer(stdout_ins, hover);
         } else {
@@ -421,13 +423,14 @@ impl Menu {
             || (*key == Some(i.to_string()))
             || (*key == Some("Enter".to_string()) && i == *hover)
           {
-            self.flush_stdout(stdout_ins);
+            self.clear_menu(stdout_ins);
             stdout_ins.flush().unwrap();
             path.push(name.to_string());
             return Ok(Selection {
               name: name.to_string(),
               path: path.to_vec(),
               value: None,
+              attempt: None,
             });
           } else {
             continue;
@@ -443,7 +446,7 @@ impl Menu {
             || (*key == Some(i.to_string()))
             || (*key == Some("Enter".to_string()) && i == *hover)
           {
-            self.flush_stdout(stdout_ins);
+            self.clear_menu(stdout_ins);
             path.push(name.to_string());
             let sub_menu = Menu {
               name: name.to_string(),
@@ -473,7 +476,7 @@ impl Menu {
             || (*key == Some(i.to_string()))
             || (*key == Some("Enter".to_string()) && i == *hover)
           {
-            self.flush_stdout(stdout_ins);
+            self.clear_menu(stdout_ins);
             path.push(name.to_string());
             let sub_menu = Menu {
               name: name.to_string(),
@@ -525,53 +528,60 @@ impl Menu {
             || (*key == Some("Enter".to_string()) && i == *hover)
           {
             // (done): flush
-            self.flush_stdout(stdout_ins);
+            self.clear_menu(stdout_ins);
             path.push(name.to_string());
-            // (done): read line
+            // (done): print
             self.print_top(path);
             self.print_name(name, exp);
             // (done): selection
+            let mut attempt = 1;
             let input = self.read_line_string();
-            // (done): match input
             let selection = match item {
               Item::Char { .. } => {
-                let value: char = self.match_input(input);
+                let value: char = self.match_input(input, &mut attempt);
                 Selection {
                   name: name.to_string(),
                   path: path.to_vec(),
                   value: Some(Value::Char(value)),
+                  attempt: Some(attempt),
                 }
               }
               Item::F64 { .. } => {
-                let value: f64 = self.match_input(input);
+                let value: f64 = self.match_input(input, &mut attempt);
                 Selection {
                   name: name.to_string(),
                   path: path.to_vec(),
                   value: Some(Value::F64(value)),
+                  attempt: Some(attempt),
                 }
               }
               Item::I64 { .. } => {
-                let value: i64 = self.match_input(input);
+                let value: i64 = self.match_input(input, &mut attempt);
                 Selection {
                   name: name.to_string(),
                   path: path.to_vec(),
                   value: Some(Value::I64(value)),
+                  attempt: Some(attempt),
                 }
               }
               Item::U64 { .. } => {
-                let value: u64 = self.match_input(input);
+                let value: u64 = self.match_input(input, &mut attempt);
                 Selection {
                   name: name.to_string(),
                   path: path.to_vec(),
                   value: Some(Value::U64(value)),
+                  attempt: Some(attempt),
                 }
               }
               _ => Selection {
                 name: name.to_string(),
                 path: path.to_vec(),
                 value: Some(Value::String(input)),
+                attempt: Some(attempt),
               },
             };
+            self.clear_lines(stdout_ins, (3 + attempt) as u16);
+            stdout_ins.flush().unwrap();
             return Ok(selection);
           } else {
             continue;
@@ -581,15 +591,17 @@ impl Menu {
     }
     Err("No Selection".to_string())
   }
-  fn flush_stdout(&self, stdout_ins: &mut Stdout) {
-    let rows = 3;
+  fn clear_lines(&self, stdout_ins: &mut Stdout, lines: u16) {
     stdout_ins
-      .queue(cursor::MoveUp(self.items.len() as u16 + rows))
+      .queue(cursor::MoveUp(lines))
       .expect("cursor move up");
     stdout_ins
       .queue(terminal::Clear(ClearType::FromCursorDown))
       .expect("terminal clear");
   }
+  fn clear_menu(&self, stdout_ins: &mut Stdout) {
+    self.clear_lines(stdout_ins, (self.items.len() + 3) as u16);
+  }
   fn print_hotkey(&self, index: &usize, hotkey: &Option<char>) {
     print!("{}{}", index.to_string().yellow(), ".".dark_grey());
     match hotkey {
@@ -646,12 +658,13 @@ impl Menu {
     stdin().read_line(&mut input).expect("read line");
     input.trim().to_string()
   }
-  fn match_input<T: FromStr>(&self, input: String) -> T {
+  fn match_input<T: FromStr>(&self, input: String, attempt: &mut i32) -> T {
     match input.parse() {
       Ok(ok) => ok,
       Err(_) => {
+        *attempt += 1;
         let input = self.read_line_string();
-        self.match_input(input)
+        self.match_input(input, attempt)
       }
     }
   }
